@@ -1,17 +1,17 @@
 config = {
   "production": {
     "api": {
-      "url": "https://app.inscribe.ai",
+      "url": "https://api.inscribe.ai",
     }
   },
   "staging": {
     "api": {
-      "url": "https://staging.inscribe.ai",
+      "url": "https://staging-api.inscribe.ai",
     }
   },
   "development": {
     "api": {
-      "url": "http://127.0.0.1:8001",
+      "url": "https://local-api.inscribe.ai",
     }
   },
   "test": {
@@ -19,4 +19,4 @@ config = {
       "url": "http://127.0.0.1:8001",
     }
   }
-}
\ No newline at end of file
+}
